"""SpellChecker Module"""

from spellchecker.info import (  # noqa: F401
    __author__,
    __bugtrack_url__,
    __credits__,
    __email__,
    __license__,  # noqa: F401
    __maintainer__,
    __url__,
    __version__,
)
from spellchecker.spellchecker import SpellChecker, WordFrequency

__all__ = ["SpellChecker", "WordFrequency"]



"""SpellChecker Information"""

__author__ = "Tyler Barrus"
__maintainer__ = "Tyler Barrus"
__email__ = "barrust@gmail.com"
__license__ = "MIT"
__version__ = "0.9.0"
__credits__ = ["Peter Norvig"]
__url__ = "https://github.com/barrust/pyspellchecker"
__bugtrack_url__ = f"{__url__}/issues"
